<?php

namespace Drp\IOEngage\Responses;

use Carbon\Carbon;
use Drp\IOEngage\Exceptions\AuthenticationFailed;
use Illuminate\Support\Arr;

class TokenResponse extends Response
{
    /** @var array<string> */
    protected $fields = [
        'access_token',
        'expires_in',
    ];

    /** @var string */
    protected $exception = AuthenticationFailed::class;

    public function token(): string
    {
        return Arr::get($this->data, 'access_token');
    }

    /**
     * Returns Carbon object for expiry time
     */
    public function expiry(): Carbon
    {
        return Carbon::now()->addSeconds(Arr::get($this->data, 'expires_in'));
    }

    public function forCache(): array
    {
        return [
            'access_token' => $this->token(),
            'expires_in' => $this->expiry(),
        ];
    }
}
