<?php

namespace Drp\IOEngage\Tests\Unit\Responses;

use Drp\IOEngage\Exceptions\DelegateRetrievalFailed;
use Drp\IOEngage\Responses\DelegateResponse;
use Drp\IOEngage\Tests\TestCase;

class DelegateResponseTest extends TestCase
{
    /** @test */
    public function can_get_delegates_collection_from_response()
    {
        $response = new DelegateResponse([
            'ValidRecordCount' => 5,
            'ValidResults' => [
                [
                    'FirstName' => 'Ken',
                ],
                [
                    'FirstName' => 'Barbie',
                ],
                [
                    'FirstName' => 'Janice',
                ],
                [
                    'FirstName' => 'Cleveland',
                ],
                [
                    'FirstName' => 'Graham',
                ],
            ],
            'InvalidRecordCount' => 0,
            'InvalidResults' => [],
        ]);

        $this->assertCount(5, $response->delegates());
        $this->assertEquals(5, $response->ValidRecordCount);
    }

    /** @test */
    public function can_get_failed_delegates_collection_from_response()
    {
        $response = new DelegateResponse([
            'InvalidRecordCount' => 5,
            'InvalidResults' => [
                [
                    'FirstName' => 'Ken',
                ],
                [
                    'FirstName' => 'Barbie',
                ],
                [
                    'FirstName' => 'Janice',
                ],
                [
                    'FirstName' => 'Cleveland',
                ],
                [
                    'FirstName' => 'Graham',
                ],
            ],
            'ValidRecordCount' => 1,
            'ValidResults' => [
                [
                    'FirstName' => 'Tim',
                ]
            ],
        ]);

        $this->assertCount(5, $response->failed());
        $this->assertEquals(5, $response->InvalidRecordCount);
    }

    /** @test */
    public function payload_validation_fails_without_keys()
    {
        $this->expectException(DelegateRetrievalFailed::class);

        new DelegateResponse([
            'ValidRecordCount' => 5,
            'ValidResults' => [
                [
                    'FirstName' => 'Ken',
                ],
                [
                    'FirstName' => 'Barbie',
                ],
                [
                    'FirstName' => 'Janice',
                ],
                [
                    'FirstName' => 'Cleveland',
                ],
                [
                    'FirstName' => 'Graham',
                ],
            ],
        ]);
    }
}
